Overview – Samplics Documentation
Description: Documentation of the Python package Samplics for statistical design and analysis of complex samples

# Overview

Sample size calculation and allocation is usually one of the first steps in conducting a survey. Sample size calculations allow the survey implementers to collect enough data o achieve targeted precision levels. To do so, the sample size calculation should follow as close as possible the actual sampling design and take into account imperfections of survey implementations such as non response. Since sample sizes are calculated prior to implementing the survey, many of the input data needed to calculate sample sizes are obtained from previous experience and from reasonable assumptions.

In this tutorial, we illustrate the calculation and allocation of some common sample size methods. Users can found additional details from Chow et al. (2018) and Ryan (2013).

Section 1: Sample size calculation for stage sampling

## References

Chow, S., Shao J., Wang H., and Y. Lokhnygina. 2018. Sample Size Calculations in Clinical Research, Third Edition. Chapman; Hall/CRC. https://doi.org/10.1201/9781315183084.
Ryan, T P. 2013. Sample Size Determination and Power. John Wiley & Sons, Inc. https://doi.org/10.1002/9781118439241.